aboutsummaryrefslogtreecommitdiff
path: root/gdb/vax-tdep.h
diff options
context:
space:
mode:
authorAndrew Cagney <cagney@redhat.com>2003-10-02 20:28:31 +0000
committerAndrew Cagney <cagney@redhat.com>2003-10-02 20:28:31 +0000
commit12c266ea569cae11221236dd5844f4136465ec88 (patch)
tree85b3c4f2e37d517888ffcadaf37ad986c1ad7c2c /gdb/vax-tdep.h
parente3b1168e9d33402a660dcc28eee716c65405bc06 (diff)
downloadfsf-binutils-gdb-12c266ea569cae11221236dd5844f4136465ec88.zip
fsf-binutils-gdb-12c266ea569cae11221236dd5844f4136465ec88.tar.gz
fsf-binutils-gdb-12c266ea569cae11221236dd5844f4136465ec88.tar.bz2
2003-10-02 Andrew Cagney <cagney@redhat.com>
* gdbarch.sh (DEPRECATED_REGISTER_RAW_SIZE): Rename REGISTER_RAW_SIZE. * gdbarch.h, gdbarch.c: Re-generate. * aix-thread.c, alpha-tdep.h, arm-tdep.c, core-sol2.c: Update. * cris-tdep.c, dve3900-rom.c, findvar.c, frame.c: Update. * hppa-tdep.c, hppab-nat.c, hppah-nat.c, hppam3-nat.c: Update. * hpux-thread.c, i386gnu-nat.c, ia64-aix-nat.c: Update. * ia64-linux-nat.c, ia64-tdep.c, infcmd.c, infptrace.c: Update. * infrun.c, irix5-nat.c, lynx-nat.c, mips-linux-tdep.c: Update. * mips-nat.c, mips-tdep.c, mipsv4-nat.c, mn10300-tdep.c: Update. * monitor.c, ns32k-tdep.c, ppc-linux-nat.c, regcache.c: Update. * remote-e7000.c, remote-mips.c, remote-sim.c: Update. * remote-vxmips.c, remote-vxsparc.c, remote.c: Update. * rom68k-rom.c, rs6000-nat.c, rs6000-tdep.c, s390-tdep.c: Update. * sh64-tdep.c, sparc-nat.c, sparc-tdep.c, stack.c: Update. * target.c, tracepoint.c, v850-tdep.c, v850ice.c, valops.c: Update. * vax-tdep.c, vax-tdep.h, x86-64-tdep.c, xstormy16-tdep.c: Update. * config/m68k/tm-delta68.h, config/m68k/tm-vx68.h: Update. * config/sparc/tm-sparc.h, config/sparc/tm-sparclynx.h: Update. 2003-10-02 Andrew Cagney <cagney@redhat.com> * gdbint.texinfo (Target Architecture Definition): Rename REGISTER_RAW_SIZE to DEPRECATED_REGISTER_RAW_SIZE. * gdb.texinfo (Packets, Stop Reply Packets): Ditto. * gdbint.texinfo (Target Architecture Definition): Rename 2003-10-02 Andrew Cagney <cagney@redhat.com> * mi-main.c: Rename REGISTER_RAW_SIZE to DEPRECATED_REGISTER_RAW_SIZE.
Diffstat (limited to 'gdb/vax-tdep.h')
-rw-r--r--gdb/vax-tdep.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/gdb/vax-tdep.h b/gdb/vax-tdep.h
index e81caed..1a19917 100644
--- a/gdb/vax-tdep.h
+++ b/gdb/vax-tdep.h
@@ -22,7 +22,7 @@
#define VAX_TDEP_H
/* Say how long (ordinary) registers are. This is a piece of bogosity
- used in push_word and a few other places; REGISTER_RAW_SIZE is the
+ used in push_word and a few other places; DEPRECATED_REGISTER_RAW_SIZE is the
real way to know how big a register is. */
#define VAX_REGISTER_SIZE 4
@@ -33,7 +33,7 @@
register state. */
#define VAX_REGISTER_BYTES (VAX_NUM_REGS * 4)
/* Largest value REGISTER_RAW_SIZE can have. */
#define VAX_MAX_REGISTER_RAW_SIZE 4
/* Largest value DEPRECATED_REGISTER_VIRTUAL_SIZE can have. */
@@ -33,7 +33,7 @@
register state. */
#define VAX_REGISTER_BYTES (VAX_NUM_REGS * 4)
-/* Largest value REGISTER_RAW_SIZE can have. */
+/* Largest value DEPRECATED_REGISTER_RAW_SIZE can have. */
#define VAX_MAX_REGISTER_RAW_SIZE 4
/* Largest value DEPRECATED_REGISTER_VIRTUAL_SIZE can have. */